==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=nl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'Je zal alle hadtekening van deze petutie uitwissen. Wil je echt verder gaan ?',
	'aucune_signature' => 'Geen handtekening',

	// B
	'bouton_checkbox_envoi_message' => 'mogelijkheid om een boodschap te laten',
	'bouton_checkbox_indiquer_site' => 'verplicht een website aan te geven',
	'bouton_checkbox_signature_unique_email' => 'enkel een handtekening per email address',
	'bouton_checkbox_signature_unique_site' => 'een enkel handtekening per website',

	// F
	'filtre' => 'Filter :',
	'form_pet_adresse_site' => 'Adres van je website',
	'form_pet_aucune_signature' => 'Geen enkele naam komt overeen met deze code ...',
	'form_pet_confirmation' => 'Gelieve je handtekening te bevestigen :',
	'form_pet_deja_signe' => 'Je hebt deze tekst al ondertekend.',
	'form_pet_envoi_mail_confirmation' => 'Een elektronische bevestigingspost is zojuist naar @email@ verzonden. U zult het Web adres moeten bezoeken dat in deze post wordt vermeld om uw handtekening te valideren.',
	'form_pet_mail_confirmation' => 'Hallo,

Je hebt gevraagd om deze petitie te ondertekenen :
@titre@.

Je hebt ons de volgende informatie bezorgd :
    Naam: @nom_email@
    Site: @nom_site@ - @url_site@
    @message@

BELANGRIJK...
Om je gegevens te valideren, volstaat het het onderstaande adres
 aan te klikken (in het andere geval, zal je aanvraag verworpen worden) :

    @url@


Bedankt voor je deelname
',
	'form_pet_message_commentaire' => 'Een boodscap, een commentaar ?',
	'form_pet_nom_site2' => 'Naam van je website',
	'form_pet_probleme_liens' => 'Gelieve uw bericht te herbeginnen zonder internet links.',
	'form_pet_probleme_technique' => 'Technisch probleem. Inloggen is momenteel niet mogelijk.',
	'form_pet_signature_validee' => 'Je naam is goedgekeurd. Bedankt!',
	'form_pet_site_deja_enregistre' => 'Deze website is reeds geregistreerd',
	'form_pet_url_invalide' => 'De URL die je opgaf, is ongeldig.',
	'form_pet_votre_email' => 'Je e-mailadres',
	'form_pet_votre_nom' => 'Je naam of alias',
	'form_pet_votre_site' => 'Als je een website hebt, kan je ze hier vermelden',

	// I
	'icone_relancer_signataire' => 'Handtekenersbevestiging ervragen',
	'icone_relancer_signataires' => 'Handtekenersbevestigingen ervragen',
	'icone_suivi_petitions' => 'Petities volgen/beheren',
	'icone_supprimer_signature' => 'Handtekening uitwissen',
	'icone_supprimer_signatures' => 'Handtekeningen uitwissen',
	'icone_valider_signature' => 'Handtekening bevstigen',
	'icone_valider_signatures' => 'Handtekeningen bvestigen',
	'info_adresse_email' => 'E-MAIL ADRES:',
	'info_fonctionnement_petition' => 'Werkwijze van de petitie',
	'info_signature_supprimee' => 'Handtekening verwijderd',
	'info_signature_supprimee_erreur' => 'Fout : de verwijderde code komt met geen enkele handtekening overeen.',
	'info_site_web' => 'WEBSITE :',
	'info_texte_message' => 'Tekst van je boodschap',

	// L
	'lien_reponse_article' => 'Beantwoord dit artikel',

	// N
	'nombre_signatures' => '@nb@ handtekeningen',

	// S
	'sans_nom' => 'Anoniem',
	'signatures_article' => 'Handtekeningen van het artikel',
	'signatures_aucune' => 'Geen',
	'signatures_meme_auteur' => 'Handtekeninge van dezelfde auteur',
	'signatures_meme_site' => 'Handtekeningen met dezelfde website',
	'signatures_poubelle' => 'uitgewiste',
	'signatures_prop' => 'In afwachting',
	'signatures_publie' => 'Bevestigde',
	'signatures_recherche_label' => 'Handtekeningen opzoeken:',
	'signatures_toutes' => 'Alles',
	'statut_poubelle' => 'Uitgewist',
	'statut_prop' => 'In afwachting van bevestiging',
	'statut_publie' => 'Bevestigd',

	// T
	'texte_descriptif_petition' => 'Beschrijving van de petitie',
	'titre_page_controle_petition' => 'Gevolg van de petities',
	'titre_petition' => 'Petitie',
	'titre_petitions' => 'Petities',
	'titre_selection_action' => 'Selectie',
	'titre_signatures_attente' => 'Handtekeningen in fwachting van bevestigingen',
	'titre_signatures_publie' => 'Bevestigde handtekeningen',
	'titre_suivi_petition' => 'Vervolg van de petities',
	'tout_voir' => 'Alle handtekeningen zien',

	// U
	'une_signature' => '1 handtekening',

	// V
	'voir_signatures_objet' => 'De handtekeningen zien'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=nl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'Je zal alle handtekening van deze petitie uitwissen. Wil je echt verder gaan?',
	'aucune_signature' => 'Geen handtekening',

	// B
	'bouton_checkbox_envoi_message' => 'mogelijkheid om een bericht te zenden',
	'bouton_checkbox_indiquer_site' => 'verplicht een website aan te geven',
	'bouton_checkbox_signature_unique_email' => 'slechts één handtekening per email adres',
	'bouton_checkbox_signature_unique_site' => 'één enkele handtekening per website',
	'bouton_radio_activer_petition' => 'Petitie activeren',
	'bouton_radio_pas_petition' => 'Geen petitie',
	'bouton_radio_petition_activee' => 'Petitie geactiveerd',
	'bouton_radio_supprimer_petition' => 'De petitie verwijderen',

	// F
	'filtre' => 'Filter :',
	'form_pet_adresse_site' => 'Adres van je website',
	'form_pet_aucune_signature' => 'Geen enkele naam komt overeen met deze code ...',
	'form_pet_confirmation' => 'Gelieve je handtekening te bevestigen :',
	'form_pet_deja_signe' => 'Je hebt deze tekst al ondertekend.',
	'form_pet_envoi_mail_confirmation' => 'Een elektronisch bevestigingsbericht is zojuist naar @email@ verzonden. U zult het Web adres moeten bezoeken dat in dit bericht wordt vermeld om uw handtekening te valideren.',
	'form_pet_mail_confirmation' => 'Hallo,

Je hebt gevraagd om deze petitie te ondertekenen :
@titre@.

Je hebt ons de volgende informatie bezorgd :
    Naam: @nom_email@
    Site: @nom_site@ - @url_site@
    @message@

BELANGRIJK...
Om je gegevens te valideren, volstaat het het onderstaande adres
 aan te klikken (anders zal je aanvraag verworpen worden):

    @url@


Bedankt voor je deelname
',
	'form_pet_message_commentaire' => 'Een boodschap, een commentaar ?',
	'form_pet_nom_site2' => 'Naam van je website',
	'form_pet_probleme_liens' => 'Gelieve uw bericht te herbeginnen zonder internet links.',
	'form_pet_probleme_technique' => 'Technisch probleem. Inloggen is momenteel niet mogelijk.',
	'form_pet_signature_validee' => 'Je naam is goedgekeurd. Bedankt!',
	'form_pet_site_deja_enregistre' => 'Deze website is reeds geregistreerd',
	'form_pet_url_invalide' => 'De URL die je opgaf, is ongeldig.',
	'form_pet_votre_email' => 'Je e-mailadres',
	'form_pet_votre_nom' => 'Je naam of alias',
	'form_pet_votre_site' => 'Als je een website hebt, kan je ze hier vermelden',

	// I
	'icone_relancer_signataire' => 'Bevestiging handtekening opnieuw versturen',
	'icone_relancer_signataires' => 'Bevestigingen handtekening opnieuw versturen',
	'icone_suivi_petitions' => 'Petities volgen/beheren',
	'icone_supprimer_signature' => 'Handtekening uitwissen',
	'icone_supprimer_signatures' => 'Handtekeningen uitwissen',
	'icone_valider_signature' => 'Handtekening bevstigen',
	'icone_valider_signatures' => 'Handtekeningen bevestigen',
	'info_adresse_email' => 'E-MAIL ADRES:',
	'info_fonctionnement_petition' => 'Werkwijze van de petitie',
	'info_signature_supprimee' => 'Handtekening verwijderd',
	'info_signature_supprimee_erreur' => 'Fout : de verwijderde code komt met geen enkele handtekening overeen.',
	'info_site_web' => 'WEBSITE :',
	'info_texte_message' => 'Tekst van je boodschap',

	// L
	'lien_reponse_article' => 'Beantwoord dit artikel',

	// N
	'nombre_signatures' => '@nb@ handtekeningen',

	// S
	'sans_nom' => 'Anoniem',
	'signatures_article' => 'Handtekeningen van het artikel',
	'signatures_aucune' => 'Geen',
	'signatures_meme_auteur' => 'Handtekeninge van dezelfde auteur',
	'signatures_meme_site' => 'Handtekeningen met dezelfde website',
	'signatures_poubelle' => 'uitgewiste',
	'signatures_prop' => 'In afwachting',
	'signatures_publie' => 'Bevestigde',
	'signatures_recherche_label' => 'Handtekeningen opzoeken:',
	'signatures_selection' => 'Handtekeningen kiezen:',
	'signatures_toutes' => 'Alles',
	'statut_poubelle' => 'Uitgewist',
	'statut_prop' => 'In afwachting van bevestiging',
	'statut_publie' => 'Bevestigd',

	// T
	'texte_descriptif_petition' => 'Beschrijving van de petitie',
	'titre_page_controle_petition' => 'Opvolgen van petities',
	'titre_petition' => 'Petitie',
	'titre_petitions' => 'Petities',
	'titre_selection_action' => 'Selectie',
	'titre_signatures_attente' => 'Handtekeningen in fwachting van bevestigingen',
	'titre_signatures_publie' => 'Bevestigde handtekeningen',
	'titre_suivi_petition' => 'Vervolg van de petities',
	'tout_voir' => 'Alle handtekeningen zien',

	// U
	'une_signature' => '1 handtekening',

	// V
	'voir_signatures_objet' => 'De handtekeningen zien'
);

?>
